==> haskell-fdo-notify-0.3.1-87-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-1jX50nf99fD7TSNqYSNsAG
key: fdo-notify-0.3.1-1jX50nf99fD7TSNqYSNsAG
license: BSD-3-Clause
maintainer: max.rabkin@gmail.com
author: Max Rabkin
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
abi: d6be2fa69b8a330fdc0df41a0aebccfc
exposed: True
exposed-modules:
    DBus.Notify
import-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-1jX50nf99fD7TSNqYSNsAG
depends:
    base-4.11.1.0 containers-0.5.11.0 dbus-1.0.1-KXotZDRAtjZ98xLNUxhNzf
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             dbus-1.0.1-KXotZDRAtjZ98xLNUxhNzf=5d74837d519baa6520e6fb659b1f876f
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fdo-notify-0.3.1-90-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fdo-notify.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fdo-notify
version: 0.3.1
id: fdo-notify-0.3.1-4gOI4QmOybG3ldT7g4cMzY
key: fdo-notify-0.3.1-4gOI4QmOybG3ldT7g4cMzY
license: BSD-3-Clause
maintainer: max.rabkin@gmail.com
author: Max Rabkin
homepage: http://bitbucket.org/taejo/fdo-notify/
synopsis: Desktop Notifications client
description:
    A library for issuing notifications using FreeDesktop.org'\''s Desktop
    Notifications protcol. This protocol is supported by services such
    as Ubuntu'\''s NotifyOSD.
category: Desktop
abi: eb5f97dd9c186551411fd0223831b82c
exposed: True
exposed-modules:
    DBus.Notify
import-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/fdo-notify-0.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/fdo-notify-0.3.1
hs-libraries: HSfdo-notify-0.3.1-4gOI4QmOybG3ldT7g4cMzY
depends:
    base-4.11.1.0 containers-0.5.11.0 dbus-1.0.1-HHfhbwZNd2bHLPQcHm2eXF
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             dbus-1.0.1-HHfhbwZNd2bHLPQcHm2eXF=7260729343b73bd278f595cbf621ff88
haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
haddock-html: /usr/share/doc/haskell-fdo-notify/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
